################################################################################
# Function name: monoToneBlack
# Parameters:
#     -picture: the image to be converted to monotone black color
# Description:
#    Loops through the pixels in the picture and extracts the RBG values for 
#    each pixel.  Pixels in the lower 128 RGB values are set to black.  Pixels
#    in the upper 128 RGB values are set to white.
################################################################################
def monoToneBlack(picture):
  show(picture)

  #ranges for upper and lower 128 RGB values
  lowerRange = range(0, 127)
  upperRange = range(128, 255)

  #loop through the pixels
  for p in getPixels(picture):
    #get the RGB values
    r = getRed(p)
    g = getGreen(p)
    b = getBlue(p)

    #get the average of the 3 values
    v = (r+g+b)/3

    #set to black if in lower half
    if(v in lowerRange):
      setColor(p, black)

    #set to white if in upper half
    if(v in upperRange):
      setColor(p, white)

  #refresh the image
  repaint(picture)

################################################################################
# Function name: monoToneRed
# Parameters:
#     -picture: the image to be converted to monotone red color
# Description:
#    Loops through the pixels in the picture and extracts the RBG values for 
#    each pixel.  Pixels in the lower 128 RGB values are set to red.  Pixels
#    in the upper 128 RGB values are set to white.
################################################################################
def monoToneRed(picture):
  show(picture)

  lowerRange = range(0, 127)
  upperRange = range(128, 255)

  #loop through the pixels
  for p in getPixels(picture):
    #get the RGB values
    r = getRed(p)
    g = getGreen(p)
    b = getBlue(p)

    #get the average of the 3 values
    v = (r+g+b)/3

    #set to red if in lower half
    if(v in lowerRange):
      setColor(p, red)

    #set to white if in upper half
    if(v in upperRange):
      setColor(p, white)

  #refresh the image
  repaint(picture)