################################################################################
# Function name: posterize
# Parameters:
#     -picture: the image to be posterized
#     -level: a value between 2 and 255 that defines the 
#              number of levels of posterization
# Description:
#    Loops through the pixels in the picture and extracts the RBG values for 
#    each pixel.  A comparison is made to see if the RBG values fall within
#    a particular range, and if so sets the value to the middle of that range.  
#    This lowers the number of colors in the image and provides a 
#    "painting/sketch" version of the image.
################################################################################
def posterize(picture, level):
  show(picture)

  #get increment value per level
  inc = 255/level

  #loop through the pixels
  for p in getPixels(picture):
    #get the RGB values
    r = getRed(p)
    g = getGreen(p)
    b = getBlue(p)

    #loop through each range
    for i in range(0, level):
      #calculate the lower and upper bounds for the range
      bottomValue = i * inc
      topValue = (i + 1) * inc

      #calculate the range midpoint which will be the new color value
      newValue = (bottomValue + topValue)/2

      #check range for RGB values
      if(r > bottomValue and r < topValue):
        setRed(p, newValue)
      if(g > bottomValue and g < topValue):
        setGreen(p, newValue)
      if(b > bottomValue and b < topValue):
        setBlue(p, newValue)

  #refresh the image to see posterization
  repaint(picture)